/*
 * Some simple UART IO functions.
 *  modified from AVRFreaks
 */

#include <stdio.h>		/* used for string manipulation procedures */
#include <avr/io.h>		/* direct access to the AVRs IO ports/SFRs */
#include <avr/pgmspace.h>	/* for accessing strings in program memory */
#include <ctype.h>		/* to convert characters from upper to lowercase */
#include "avrutils.h"
uint8_t chipMemory[CHIPMEMSIZE];
/*
 * Send character c down the UART Tx, wait until tx holding register
 * is empty.
 */
void putchr(char c)
{
	loop_until_bit_is_set(UCSR0A, UDRE0);
	UDR0 = c;
}

/* Get a character from the UART Rx, wait until the rx holding register
 * is set
 */
char getchr(void)
{
	loop_until_bit_is_set(UCSR0A, RXC0);
	return UDR0;
}

/*
 * Send a C (NUL-terminated) string down the UART Tx.
 */
void printstr(const char *s)
{
	while (*s) {
		if (*s == '\n')
			putchr('\r');
		putchr(*s++);
	}
}

/*
 * Same as above, but the string is located in program memory,
 * so "lpm" instructions are needed to fetch it.
 */
void printstr_p(const char *s)
{
	char c;

	for (c = pgm_read_byte(s); c; ++s, c = pgm_read_byte(s)) {
		if (c == '\n')
			putchr('\r');
		putchr(c);
	}
}

/*
 * returns a char given a received ascii character
 */
unsigned char ascii_to_bin(char data)
{
	if (data < 'A') {
		return (data - '0');
	} else {
		return (data - 55);
	}
}

/*end simple IO functions */

void printhex(uint8_t print_byte)
{
	char string_byte[3];
	sprintf(string_byte, "%02X", print_byte);
	printstr(string_byte);
}
